@@ -1,6 +1,6 @@
 from abc import ABC
 
-from dandy.processor.processor import BaseProcessor
+from dandy.core.processor.processor import BaseProcessor
 
 
 class BaseBot(BaseProcessor, ABC):
