@@ -1,3 +1,12 @@
+__VERSION__ = '0.12.0'
+
+# Cache
+
+SQLITE_CACHE_TABLE_NAME = 'cache'
+DEFAULT_CACHE_NAME: str = 'dandy'
+
+# CLI
+
 CLI_OUTPUT_DIRECTORY = '.dandy_cli_output'
 CLI_DEFAULT_ENV_FILE_NAMES = [
     'dandy.env',
@@ -6,11 +15,16 @@ CLI_DEFAULT_ENV_FILE_NAMES = [
     '.env',
 ]
 
-ESTIMATED_CHARACTERS_PER_TOKEN = 4
+# Debug
 
 DEBUG_OUTPUT_DIRECTORY = '.dandy_debug_output'
 
+# LLM
+
+ESTIMATED_CHARACTERS_PER_TOKEN = 4
+
+# Settings
+
 DEFAULT_SETTINGS_MODULE = 'dandy_settings'
 DEFAULT_SETTINGS_FILE_NAME = f'{DEFAULT_SETTINGS_MODULE}.py'
 
-VERSION = '0.11.0'
