@@ -15,10 +15,11 @@ DEFAULT_LLM_SEED: int = 77
 DEFAULT_LLM_RANDOMIZE_SEED: bool = False
 DEFAULT_LLM_MAX_INPUT_TOKENS: int = 8000
 DEFAULT_LLM_MAX_OUTPUT_TOKENS: int = 4000
-DEFAULT_LLM_CONNECTION_RETRY_COUNT: int = 10
 DEFAULT_LLM_PROMPT_RETRY_COUNT: int = 2
 DEFAULT_LLM_REQUEST_TIMEOUT: Union[int, None] = None
 
+HTTP_CONNECTION_RETRY_COUNT: int = 10
+
 LLM_CONFIGS = {
     # 'DEFAULT': {
     #     'TYPE': 'ollama',
